==> openjdk-src-15.0.2.u7-1-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_mni.java <==
/*
 * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_mni extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "BR", "\u09ac\u09cd\u09b0\u09be\u099c\u09bf\u09b2" },
            { "CN", "\u099a\u09bf\u09a8\u09be" },
            { "DE", "\u099c\u09b0\u09cd\u09ae\u09a8\u09bf" },
            { "FR", "\u09ab\u09cd\u09b0\u09be\u09a8\u09cd\u09b8" },
            { "GB", "\u09af\u09bc\u09c1\u09a8\u09be\u0987\u099f\u09c7\u09a6 \u0995\u09bf\u0982\u09a6\u09ae" },
            { "IN", "\u0987\u09a8\u09cd\u09a6\u09bf\u09af\u09bc\u09be" },
            { "IT", "\u0987\u099f\u09be\u09b2\u09bf" },
            { "JP", "\u099c\u09be\u09aa\u09be\u09a8" },
            { "RU", "\u09b0\u09c1\u09b8\u09bf\u09af\u09bc\u09be" },
            { "US", "\u09af\u09bc\u09c1\u09a8\u09be\u0987\u099f\u09c7\u09a6 \u09b7\u09cd\u099f\u09c7\u099f\u09b8" },
            { "ZZ", "\u09ae\u09b6\u0995\u0996\u0982\u09a6\u09ac\u09be \u09b2\u09ae\u09a6\u09ae" },
            { "de", "\u099c\u09b0\u09cd\u09ae\u09a8" },
            { "en", "\u0987\u0982\u09b2\u09bf\u09b8" },
            { "es", "\u09b8\u09cd\u09aa\u09c7\u09a8\u09bf\u09b8" },
            { "fr", "\u09ab\u09cd\u09b0\u09c7\u099e\u09cd\u099a" },
            { "it", "\u0987\u099f\u09be\u09b2\u09bf\u09af\u09bc\u09be\u09a8" },
            { "ja", "\u099c\u09be\u09aa\u09be\u09a8\u09bf\u099c" },
            { "pt", "\u09aa\u09cb\u09b0\u09cd\u099f\u09c1\u0997\u09bf\u099c" },
            { "ru", "\u09b0\u09c1\u09b8\u09bf\u09af\u09bc\u09be\u09a8" },
            { "zh", "\u099a\u09be\u0987\u09a8\u09bf\u099c" },
            { "mni", "\u09ae\u09c8\u09a4\u09c8\u09b2\u09cb\u09a8\u09cd" },
            { "und", "\u09ae\u09b6\u0995\u0996\u0982\u09a6\u09ac\u09be \u09b2\u09cb\u09b2" },
            { "Arab", "\u0986\u09b0\u09ac\u09bf\u0995" },
            { "Beng", "\u09ac\u09be\u0982\u09b2\u09be" },
            { "Cyrl", "\u09b8\u09bf\u09b0\u09bf\u09b2\u09bf\u0995" },
            { "Hans", "\u09b8\u09bf\u09ae\u09aa\u09cd\u09b2\u09bf\u09ab\u09be\u0987\u09a6" },
            { "Hant", "\u09a4\u09cd\u09b0\u09c7\u09a6\u09bf\u09b8\u09cd\u09a8\u09c7\u09b2" },
            { "Latn", "\u09b2\u09c7\u099f\u09bf\u09a8" },
            { "Mtei", "\u09ae\u09c7\u0987\u099f\u09c7\u0987 \u09ae\u09be\u09af\u09bc\u09c7\u0995" },
            { "Zxxx", "\u0987\u09a6\u09ac\u09be" },
            { "Zzzz", "\u09ae\u09b6\u0995\u0996\u0982\u09a6\u09ac\u09be \u09b8\u09cd\u0995\u09cd\u09b0\u09bf\u09aa\u09cd\u099f" },
            { "de_AT", "\u0993\u09b7\u09cd\u099f\u09cd\u09b0\u09bf\u09af\u09bc\u09be\u09a8 \u099c\u09b0\u09cd\u09ae\u09a8" },
            { "de_CH", "\u09b8\u09cd\u09ac\u09bf\u099c \u09b9\u09be\u09af\u09bc \u099c\u09b0\u09cd\u09ae\u09a8" },
            { "en_AU", "\u0993\u09b7\u09cd\u099f\u09cd\u09b0\u09c7\u09b2\u09bf\u09af\u09bc\u09be\u09a8 \u0987\u0982\u09b2\u09bf\u09b8" },
            { "en_CA", "\u0995\u09be\u09a8\u09be\u09a6\u09bf\u09af\u09bc\u09be\u09a8 \u0987\u0982\u09b2\u09bf\u09b8" },
            { "en_GB", "\u09ac\u09cd\u09b0\u09bf\u099f\u09bf\u09b6 \u0987\u0982\u09b2\u09bf\u09b8" },
            { "en_US", "\u0985\u09ae\u09c7\u09b0\u09bf\u0995\u09be\u09a8 \u0987\u0982\u09b2\u09bf\u09b8" },
            { "fr_CA", "\u0995\u09be\u09a8\u09be\u09a6\u09bf\u09af\u09bc\u09be\u09a8 \u09ab\u09cd\u09b0\u09c7\u099e\u09cd\u099a" },
            { "fr_CH", "\u09b8\u09cd\u09ac\u09bf\u099c \u09ab\u09cd\u09b0\u09c7\u099e\u09cd\u099a" },
            { "pt_BR", "\u09ac\u09cd\u09b0\u09be\u099c\u09bf\u09b2\u09bf\u09af\u09bc\u09be\u09a8 \u09aa\u09cb\u09b0\u09cd\u099f\u09c1\u0997\u09bf\u099c" },
            { "pt_PT", "\u09af\u09bc\u09c1\u09b0\u09cb\u09aa\u09bf\u09af\u09bc\u09be\u09a8 \u09aa\u09cb\u09b0\u09cd\u099f\u09c1\u0997\u09bf\u099c" },
            { "es_419", "\u09b2\u09c7\u099f\u09bf\u09a8 \u0985\u09ae\u09c7\u09b0\u09bf\u0995\u09be\u09a8 \u09b8\u09cd\u09aa\u09c7\u09a8\u09bf\u09b8" },
            { "zh_Hans", "\u09b8\u09bf\u09ae\u09aa\u09cd\u09b2\u09bf\u09ab\u09be\u0987\u09a6 \u099a\u09be\u0987\u09a8\u09bf\u099c" },
            { "zh_Hant", "\u09a4\u09cd\u09b0\u09c7\u09a6\u09bf\u09b8\u09cd\u09a8\u09c7\u09b2 \u099a\u09be\u0987\u09a8\u09bf\u099c" },
            { "type.nu.beng", "\u09ac\u09be\u0982\u09b2\u09be \u09a6\u09bf\u099c\u09bf\u099f" },
            { "type.nu.latn", "\u09f1\u09c7\u09b8\u09cd\u09a4\u09b0\u09cd\u09a8 \u09a6\u09bf\u099c\u09bf\u099f" },
            { "type.co.standard", "\u09b7\u09cd\u099f\u09c7\u09a8\u09cd\u09a6\u09b0\u09cd\u09a6 \u09b8\u09cb\u09b0\u09cd\u099f \u0993\u09b0\u09cd\u09a6\u09b0" },
            { "type.ca.gregorian", "\u0997\u09cd\u09b0\u09bf\u0997\u09cb\u09b0\u09bf\u09af\u09bc\u09be\u09a8 \u0995\u09c7\u09b2\u09c7\u09a8\u09cd\u09a6\u09b0" },
        };
        return data;
    }
}

==> openjdk-src-25.0.2.u10-1-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_mni.java <==
/*
 * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_mni extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final String metaValue_bn = "\u09ac\u09be\u0982\u09b2\u09be";
        final String metaValue_ko = "\u0995\u09cb\u09b0\u09bf\u09af\u09bc\u09a8";
        final Object[][] data = new Object[][] {
            { "001", "\u09ae\u09be\u09b2\u09c7\u09ae" },
            { "002", "\u0985\u09ab\u09cd\u09b0\u09bf\u0995\u09be" },
            { "019", "\u0985\u09ae\u09c7\u09b0\u09bf\u0995\u09be\u09b6\u09bf\u0982" },
            { "150", "\u09af\u09bc\u09c1\u09b0\u09cb\u09aa" },
            { "BR", "\u09ac\u09cd\u09b0\u09be\u099c\u09bf\u09b2" },
            { "CN", "\u099a\u09bf\u09a8\u09be" },
            { "DE", "\u099c\u09b0\u09cd\u09ae\u09a8\u09bf" },
            { "FR", "\u09ab\u09cd\u09b0\u09be\u09a8\u09cd\u09b8" },
            { "GB", "\u09af\u09bc\u09c1\u09a8\u09be\u0987\u099f\u09c7\u09a6 \u0995\u09bf\u0982\u09a6\u09ae" },
            { "IN", "\u0987\u09a8\u09cd\u09a6\u09bf\u09af\u09bc\u09be" },
            { "IT", "\u0987\u099f\u09be\u09b2\u09bf" },
            { "JP", "\u099c\u09be\u09aa\u09be\u09a8" },
            { "RU", "\u09b0\u09c1\u09b8\u09bf\u09af\u09bc\u09be" },
            { "US", "\u09af\u09bc\u09c1\u09a8\u09be\u0987\u099f\u09c7\u09a6 \u09b7\u09cd\u099f\u09c7\u099f\u09b8" },
            { "ZZ", "\u09ae\u09b6\u0995\u0996\u0982\u09a6\u09ac\u09be \u09b2\u09ae\u09a6\u09ae" },
            { "ar", "\u0986\u09b0\u09be\u09ac\u09bf\u0995" },
            { "bn", metaValue_bn },
            { "de", "\u099c\u09b0\u09cd\u09ae\u09a8" },
            { "en", "\u0987\u0982\u09b2\u09bf\u09b8" },
            { "es", "\u09b8\u09cd\u09aa\u09c7\u09a8\u09bf\u09b8" },
            { "fr", "\u09ab\u09cd\u09b0\u09c7\u099e\u09cd\u099a" },
            { "hi", "\u09b9\u09bf\u09a8\u09cd\u09a6\u09c0" },
            { "id", "\u0987\u09a8\u09cd\u09a6\u09cb\u09a8\u09c7\u09b8\u09bf\u09af\u09bc\u09be" },
            { "it", "\u0987\u099f\u09be\u09b2\u09bf\u09af\u09bc\u09a8" },
            { "ja", "\u099c\u09be\u09aa\u09be\u09a8\u09bf\u099c" },
            { "ko", metaValue_ko },
            { "nl", "\u09a6\u099a" },
            { "pl", "\u09aa\u09cb\u09b2\u09bf\u09b6" },
            { "pt", "\u09aa\u09cb\u09b0\u09cd\u099f\u09c1\u0997\u09bf\u099c" },
            { "ru", "\u09b0\u09c1\u09b8\u09bf\u09af\u09bc\u09be\u09a8" },
            { "th", "\u09a5\u09be\u0987" },
            { "tr", "\u099f\u09b0\u09cd\u0995\u09bf\u09b6" },
            { "zh", "\u099a\u09be\u0987\u09a8\u09bf\u099c" },
            { "mni", "\u09ae\u09c8\u09a4\u09c8\u09b2\u09cb\u09a8\u09cd" },
            { "und", "\u09ae\u09b6\u0995\u0996\u0982\u09a6\u09ac\u09be \u09b2\u09cb\u09b2" },
            { "Arab", "\u0986\u09b0\u09ac\u09bf\u0995" },
            { "Beng", metaValue_bn },
            { "Cyrl", "\u09b8\u09bf\u09b0\u09bf\u09b2\u09bf\u0995" },
            { "Hans", "\u09b2\u09be\u0987\u09a5\u09cb\u0995\u09b9\u09b2\u09cd\u09b2\u09ac\u09be" },
            { "Hant", "\u09a4\u09cd\u09b0\u09c7\u09a6\u09bf\u09b8\u09cd\u09a8\u09c7\u09b2" },
            { "Jpan", "\u099c\u09aa\u09be\u09a8\u09bf\u099c" },
            { "Kore", metaValue_ko },
            { "Latn", "\u09b2\u09c7\u099f\u09bf\u09a8" },
            { "Mtei", "\u09ae\u09c0\u09a4\u09c8 \u09ae\u09af\u09bc\u09c7\u0995" },
            { "Zxxx", "\u0987\u09a6\u09ac\u09be" },
            { "Zzzz", "\u09ae\u09b6\u0995\u0996\u0982\u09a6\u09ac\u09be \u09b8\u09cd\u0995\u09cd\u09b0\u09bf\u09aa\u09cd\u099f" },
            { "de_AT", "\u0993\u09b7\u09cd\u099f\u09cd\u09b0\u09bf\u09af\u09bc\u09be\u09a8 \u099c\u09b0\u09cd\u09ae\u09a8" },
            { "de_CH", "\u09b8\u09cd\u09ac\u09bf\u099c \u09b9\u09be\u09af\u09bc \u099c\u09b0\u09cd\u09ae\u09a8" },
            { "en_AU", "\u0993\u09b7\u09cd\u099f\u09cd\u09b0\u09c7\u09b2\u09bf\u09af\u09bc\u09be\u09a8 \u0987\u0982\u09b2\u09bf\u09b8" },
            { "en_CA", "\u0995\u09be\u09a8\u09be\u09a6\u09bf\u09af\u09bc\u09be\u09a8 \u0987\u0982\u09b2\u09bf\u09b8" },
            { "en_GB", "\u09ac\u09cd\u09b0\u09bf\u099f\u09bf\u09b6 \u0987\u0982\u09b2\u09bf\u09b8" },
            { "en_US", "\u0985\u09ae\u09c7\u09b0\u09bf\u0995\u09be\u09a8 \u0987\u0982\u09b2\u09bf\u09b8" },
            { "es_ES", "\u09af\u09bc\u09c1\u09b0\u09cb\u09aa\u09bf\u09af\u09bc\u09be\u09a8 \u09b8\u09cd\u09aa\u09c7\u09a8\u09bf\u09b8" },
            { "es_MX", "\u09ae\u09c7\u0995\u09cd\u09b8\u09bf\u0995\u09be\u09a8 \u09b8\u09cd\u09aa\u09c7\u09a8\u09bf\u09b8" },
            { "fr_CA", "\u0995\u09be\u09a8\u09be\u09a6\u09bf\u09af\u09bc\u09be\u09a8 \u09ab\u09cd\u09b0\u09c7\u099e\u09cd\u099a" },
            { "fr_CH", "\u09b8\u09cd\u09ac\u09bf\u099c \u09ab\u09cd\u09b0\u09c7\u099e\u09cd\u099a" },
            { "nl_BE", "\u09ab\u09cd\u09b2\u09c7\u09ae\u09bf\u09b6" },
            { "pt_BR", "\u09ac\u09cd\u09b0\u09be\u099c\u09bf\u09b2\u09bf\u09af\u09bc\u09be\u09a8 \u09aa\u09cb\u09b0\u09cd\u099f\u09c1\u0997\u09bf\u099c" },
            { "pt_PT", "\u09af\u09bc\u09c1\u09b0\u09cb\u09aa\u09bf\u09af\u09bc\u09be\u09a8 \u09aa\u09cb\u09b0\u09cd\u099f\u09c1\u0997\u09bf\u099c" },
            { "ar_001", "\u09ae\u09cb\u09b0\u09cd\u09a6\u09b0\u09cd\u09a8 \u09b8\u09cd\u09a4\u09c7\u09a8\u09cd\u09a6\u09b0\u09cd\u09a6 \u0986\u09b0\u09be\u09ac\u09bf\u0995" },
            { "es_419", "\u09b2\u09c7\u099f\u09bf\u09a8 \u0985\u09ae\u09c7\u09b0\u09bf\u0995\u09be\u09a8 \u09b8\u09cd\u09aa\u09c7\u09a8\u09bf\u09b8" },
            { "zh_Hans", "\u09b8\u09bf\u09ae\u09aa\u09cd\u09b2\u09bf\u09ab\u09be\u0987\u09a6 \u099a\u09be\u0987\u09a8\u09bf\u099c" },
            { "zh_Hant", "\u09a4\u09cd\u09b0\u09c7\u09a6\u09bf\u09b8\u09cd\u09a8\u09c7\u09b2 \u099a\u09be\u0987\u09a8\u09bf\u099c" },
            { "type.nu.beng", "\u09ac\u09be\u0982\u09b2\u09be \u09a6\u09bf\u099c\u09bf\u099f" },
            { "type.nu.latn", "\u09f1\u09c7\u09b8\u09cd\u09a4\u09b0\u09cd\u09a8 \u09a6\u09bf\u099c\u09bf\u099f" },
            { "type.co.standard", "\u09b7\u09cd\u099f\u09c7\u09a8\u09cd\u09a6\u09b0\u09cd\u09a6 \u09b8\u09cb\u09b0\u09cd\u099f \u0993\u09b0\u09cd\u09a6\u09b0" },
            { "type.ca.gregorian", "\u0997\u09cd\u09b0\u09bf\u0997\u09cb\u09b0\u09bf\u09af\u09bc\u09be\u09a8 \u0995\u09c7\u09b2\u09c7\u09a8\u09cd\u09a6\u09b0" },
        };
        return data;
    }
}
